@@ -1,7 +1,9 @@
 from asyncpg import connection
+from sqlalchemy import func
 from sqlalchemy.dialects.postgresql import pypostgresql
 from sqlalchemy.sql import ClauseElement
 from sqlalchemy.sql.dml import Insert as InsertObject, Update as UpdateObject
+from sqlalchemy.sql.ddl import DDLElement
 
 from .log import query_logger
 
@@ -44,7 +46,9 @@ def _execute_default_attr(query, param, attr_name):
     for col in query.table.columns:
         attr = getattr(col, attr_name)
         if attr and param.get(col.name) is None:
-            if attr.is_scalar:
+            if attr.is_sequence:
+                param[col.name] = func.nextval(attr.name)
+            elif attr.is_scalar:
                 param[col.name] = attr.arg
             elif attr.is_callable:
                 param[col.name] = attr.arg({})
@@ -54,6 +58,11 @@ def compile_query(query, dialect=_dialect, inline=False):
     if isinstance(query, str):
         query_logger.debug(query)
         return query, ()
+    elif isinstance(query, DDLElement):
+        compiled = query.compile(dialect=dialect)
+        new_query = compiled.string
+        query_logger.debug(new_query)
+        return new_query, ()
     elif isinstance(query, ClauseElement):
         query = execute_defaults(query)  # default values for Insert/Update
         compiled = query.compile(dialect=dialect)
