@@ -1,3 +1,4 @@
+import asyncio
 
 
 class ConnectionTransactionContextManager:
@@ -22,7 +23,7 @@ class ConnectionTransactionContextManager:
         self.trans_kwargs = kwargs
 
     def __enter__(self):
-        raise SyntaxError('Must use "async with" for a transaction')
+        raise RuntimeError('Must use "async with" for a transaction')
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         pass
@@ -31,9 +32,18 @@ class ConnectionTransactionContextManager:
         self.acquire_context = self.pool.acquire(timeout=self.timeout)
         con = await self.acquire_context.__aenter__()
         self.transaction = con.transaction(**self.trans_kwargs)
-        await self.transaction.__aenter__()
+        try:
+            await self.transaction.__aenter__()
+        except Exception:
+            await asyncio.shield(self.acquire_context.__aexit__())
+            raise
         return con
 
     async def __aexit__(self, exc_type, exc_val, exc_tb):
-        await self.transaction.__aexit__(exc_type, exc_val, exc_tb)
-        await self.acquire_context.__aexit__(exc_type, exc_val, exc_tb)
+        async def _close():
+            try:
+                await self.transaction.__aexit__(exc_type, exc_val, exc_tb)
+            finally:
+                await self.acquire_context.__aexit__(exc_type, exc_val, exc_tb)
+
+        await asyncio.shield(_close())
